@@ -7,18 +7,13 @@
 #include "kbsrenderer.h"
 #include "coord.h"
 // KDEGames
-#include <kdegames_version.h>
-#include <KgThemeProvider>
+#include <KGameThemeProvider>
 #include <KGameRenderedItem>
 
-static KgThemeProvider *provider()
+static KGameThemeProvider *provider()
 {
-    KgThemeProvider *prov = new KgThemeProvider;
-#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
+    KGameThemeProvider *prov = new KGameThemeProvider;
     prov->discoverThemes(QStringLiteral("pictures"));
-#else
-    prov->discoverThemes("appdata", QStringLiteral("pictures"));
-#endif
     return prov;
 }
 
